Loss Functions
===============

Concept-aware loss functions with automatic routing and weighting.

.. currentmodule:: torch_concepts.nn.modules.loss

Summary
-------

**High-Level Losses**

.. autosummary::
   :toctree: generated
   :nosignatures:

   ConceptLoss
   WeightedConceptLoss

**Low-Level Losses**

.. autosummary::
   :toctree: generated
   :nosignatures:

   WeightedBCEWithLogitsLoss
   WeightedCrossEntropyLoss
   WeightedMSELoss


Class Documentation
-------------------

.. autoclass:: ConceptLoss
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: WeightedConceptLoss
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: WeightedBCEWithLogitsLoss
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: WeightedCrossEntropyLoss
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: WeightedMSELoss
   :members:
   :undoc-members:
   :show-inheritance:
